from ngsolve import *
from netgen.geom2d import unit_square
import ngsolve.solvers as solvers
from ngsolve.meshes import MakeStructured2DMesh


# a background mesh for the coefficient
bgmesh = MakeStructured2DMesh(nx=100, ny=100)
bgfes = L2(bgmesh, order=0)
bglam = GridFunction(bgfes)
bglam.Set ( IfPos(0.2**2-(x-0.5)**2-(y-0.5)**2, 1, 10))


mesh = Mesh(unit_square.GenerateMesh(maxh=0.03))

fes = H1(mesh, order=2, dirichlet=".*")
u,v = fes.TnT()

a = BilinearForm(fes)
a += bglam*grad(u)*grad(v)*dx()

f = LinearForm(fes)
f += 100*v*dx

gfu = GridFunction(fes)

solvers.BVP(a, f, gfu)
Draw(gfu)
